Rec

Type Alias Rec 

pub type Rec<T> = BorrowRec<'static, T>;
A single recursive-function result with static lifetime.

Aliased Type

pub enum Rec<T> {
    Ret(T),
    Call(Thunk<'static, BorrowRec<'static, T>>),
}

Variants



Ret(T)

This variant is returned when the function is done; i.e. this the result of the computation.



Call(Thunk<'static, BorrowRec<'static, T>>)

This variant is returned when the function is about to call itself or another in a tail position (i.e. there is no job after the call), generally indicates recursion.